#
# spec file for package atkmm
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define base_ver 2.28
# Update baselibs.conf when changing the version here
%define libname  lib%{name}-2_28-1
Name:           atkmm
Version:        2.27.1
Release:        lp151.3.2
Summary:        C++ Binding for the ATK library
License:        LGPL-2.1-or-later AND GPL-2.0-or-later AND GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://www.gtkmm.org/
Source:         http://download.gnome.org/sources/%{name}/2.27/%{name}-%{version}.tar.xz
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM atkmm-glibmm-bump.patch bjorn.lie@gmail.com -- Fix build with new glibmm2
Patch0:         atkmm-glibmm-bump.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  mm-common
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(atk) >= 1.18
BuildRequires:  pkgconfig(glibmm-2.58) >= 2.53.1.1
Recommends:     %{name}-doc = %{version}

%description
atkmm is the C++ binding for the ATK library.
This module is part of the GNOME C++ bindings effort.

%package -n %{libname}
Summary:        C++ Binding for the ATK library -- Shared Library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{libname}
atkmm is the C++ binding for the ATK library.
This module is part of the GNOME C++ bindings effort.

This package provides the ATK library's C++'s bindings shared library.

%package devel
Summary:        C++ Binding for the ATK library -- Development Files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{libname} >= %{version}

%description devel
atkmm is the C++ binding for the ATK library.
This module is part of the GNOME C++ bindings effort.

This package provides all the necessary files for development with ATK
library's C++ bindings.

%package doc
Summary:        C++ Binding for the ATK library -- Documentation
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Documentation/HTML
Requires:       glibmm2-doc
BuildArch:      noarch

%description doc
atkmm is the C++ binding for the ATK library.
This module is part of the GNOME C++ bindings effort.

This package provides the documentation files for the ATK library's
C++ bindings.

%prep
%setup -q
%patch0 -p1

%build
NOCONFIGURE=1 ./autogen.sh
export CXXFLAGS="-std=c++17 %{optflags}"
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_datadir}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%doc NEWS
%{_libdir}/libatkmm-%{base_ver}.so.*

%files devel
%{_includedir}/atkmm-%{base_ver}/
%{_libdir}/libatkmm-%{base_ver}.so
%{_libdir}/pkgconfig/atkmm-%{base_ver}.pc
%{_libdir}/atkmm-%{base_ver}/include/
%dir %{_libdir}/atkmm-%{base_ver}
%dir %{_libdir}/atkmm-%{base_ver}/proc
%{_libdir}/atkmm-%{base_ver}/proc/m4/

%files doc
%license COPYING.tools
%doc AUTHORS ChangeLog README
%{_datadir}/devhelp/books/atkmm-%{base_ver}/
%{_datadir}/doc/atkmm-%{base_ver}/
# Avoid BuildRequires on devhelp
%dir %{_datadir}/devhelp
%dir %{_datadir}/devhelp/books

%changelog
* Tue Apr 17 2018 dimstar@opensuse.org
- Export CXXFLAGS="-std=c++17" until upstream catches up. Required,
  as libsigc++-3.0 moved to C++17.
* Sat Mar 31 2018 bjorn.lie@gmail.com
- Add atkmm-glibmm-bump.patch, fix build with new glibmm2.
- Following the above, add libtool and mm-common BuildRequires and
  pass autogen.sh as the patch touches the buildsystem.
- Also replace pkgconfig(glibmm-2.56) with pkgconfig(glibmm-2.58).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Feb 24 2018 luc14n0@linuxmail.org
- Update to version 2.27.1:
  + Change ABI to atkmm-2.28.
- Update '+' in GPL/LGPL License tags to '-or-later' and add GPL
  version 2 and 3 to the preamble to comply with the copyrights.
- Update packages descriptions to show more explictly subpackages'
  content.
- Drop unneeded standard BuildRoot tag declaration: RPM already
  handles this itself.
- Point fdupes to the data directory under the build root instead
  of the build root directly, which is a practice that must be
  avoided.
- Rename shared library subpackage name to libatkmm-2_28-1 to
  follow upstream change.
- Recommends the documentation subpackage.
* Fri Aug 25 2017 zaitor@opensuse.org
- Update to version 2.25.4:
  + Build: Use glibmm-2.56 instead of glibmm-2.54. We have changed
    the ABI name in glibmm.
  + Text: Plug memory leaks in get_text_vfunc() and
    get_selection_vfunc(). These vfuncs shall delete the returned
    character array after it has been copied to a Glib::ustring
    (bgo#783360).
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 2.25.3:
  + Use C++11 enum classes instead of old-style enums, and put some
    enums inside relevant class declarations:
  - Relation: Change RelationType to Relation::Type.
  - Text: Move enums into the class.
  + Build: Windows: Visual Studio builds: Update glibmm ABI
    version.
- Changes from version 2.25.2:
  + Build: Use glibmm-2.54 instead of glibmm-2.52.
  +  (Murray Cumming)
  + Replace uses of Glib::ArrayHandle<> and Glib::SListHandle<>
    with vector.
  + Visual Studio: Require Visual Studio 2017.
* Mon Dec  5 2016 jengelh@inai.de
- Rectify rpm groups.
* Mon Dec  5 2016 dimstar@opensuse.org
- Update to version 2.25.1:
  + This is the first release of the atkmm-2.26 API/ABI.
  + Require C++14.
  + Use glibmm-2.52 instead of glibmm-2.4.
  + Fix silent builds (bgo#768797).
- Rename libatkmm-1_6-1 to libatkmm-2_26-1, following upstreams
  soname change.
- Remove outdated condition for openSUSE 11.2 (make the doc package
  unconditionally noarch).
* Fri Apr 15 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Nov 30 2015 zaitor@opensuse.org
- Update to version 2.24.2:
  + Regenerate with the latest glibmm.
* Wed Sep 30 2015 zaitor@opensuse.org
- Update to version 2.24.1:
  + Regenerate with the latest glibmm.
- Changes from version 2.24.0:
  + MSVC build fixes.
* Fri Sep  4 2015 zaitor@opensuse.org
- Update to version 2.23.3:
  + Rebuilt with latest glibmm, whose gmmproc generates C++ move
    operations.
* Sat Jul 25 2015 zaitor@opensuse.org
- Update to version 2.23.2:
  + Use (and require) C++11.
- Changes from version 2.23.1:
  + Atk:
  - Document: Add get/set_attribute() and deprecate
    get_document() and get_document_type().
  - Component: Deprecate add/remove_focus_handler, get_size() and
    get_position().
  - Add Range.
  - Table:
    . Deprecate get_column/row_at_index().
    . Add a get_at() const version and deprecate get_index_at().
  - Text:
    . Deprecate get_text_before_offset(),
    get_text_after_offset().
    . Add get_string_at_offset(), deprecating other methods for
    it.
  - Value: Deprecate get_minimum/maximum_range() in favour or
    get_range().
  + Build: Update MSVC 2005, 2008 and 2010 Projects: Add "Install"
    Project.
* Mon Apr 29 2013 dimstar@opensuse.org
- Update to version 2.22.7:
  + Remove the use of g_type_init() because it has been deprecated.
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 2.22.6:
  + Add #includes needed with the latest glibmm.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
- Add atkmm-devel to baselibs
* Thu Jul  7 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Sat Apr 30 2011 dimstar@opensuse.org
- Update to version 2.22.5:
  + bgo#645669: Install the m4 files even without
  - -enable-maintainer-mode, as with other modules.
- Use source services: download_url and set_version.
* Wed Mar 23 2011 fcrozat@novell.com
- Update to version 2.22.4:
  + Avoid a tarball dependency on mm-common.
- Changes from version 2.22.3:
  + a tarball regeneration due to a changed m4 macro in mm-common.
* Sun Jan  9 2011 vuntz@opensuse.org
- Update to version 2.22.2:
  + Install m4 files needed by recent versions of gtkmm when
    building from git.
* Tue Dec  7 2010 vuntz@opensuse.org
- Update to version 2.22.1:
  + Distribute the GPL in the tarball, in addition to the LGPL,
    because the Windows build uses a GPL builder tool.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.22.0:
  + Just increased version to show that it's an API/ABI-stable
    release.
* Fri Aug  6 2010 vuntz@opensuse.org
- Initial package: the code got split from gtkmm2.
